==> quickplot_0.1.0.orig.tar.gz: quickplot-0.1.0/icon.c <==
/***************************************************************
LanceMan's quickplot --- a fast interactive 2D plotter

Copyright (C) 1998  Lance Arsenault

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

***********************************************************************/
/* $Id: icon.c,v 1.1 1998/02/28 18:09:06 lance Exp $ */
/*
**  Create a nice icon image
*/
#include <stdio.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>

#include "QuickPlotIcon.xbm"

void SetIconImage(Widget w, Boolean flag)
{
  Pixmap pixmap;
  Pixel foreground, background;
  unsigned int depth;
  unsigned int width = QuickPlotIcon_width;
  unsigned int height = QuickPlotIcon_height;

  XtVaGetValues(w,XtNdepth, &depth, NULL);
  foreground = XBlackPixelOfScreen(XtScreen(w));
  background = XWhitePixelOfScreen(XtScreen(w));

  pixmap = XCreatePixmapFromBitmapData(
	    XtDisplay(w),
	    XRootWindowOfScreen(XtScreen(w)),
	    (char *) QuickPlotIcon_bits,
	    width,
	    height,
	    foreground,
	    background,
	    depth);
  XtVaSetValues(w, XtNiconPixmap, pixmap, NULL);

}

==> quickplot_0.4.4.orig.tar.gz: quickplot-0.4.4/icon.c <==
/***************************************************************
LanceMan's quickplot --- a fast interactive 2D plotter

Copyright (C) 1998, 1999  Lance Arsenault

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Or look at http://www.gnu.org/copyleft/gpl.html .

**********************************************************************/
/* $Id: icon.c,v 1.1 1998/02/28 18:09:06 lance Exp $ */
/*
**  Create a nice icon image
*/
#include <stdio.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>

#include "QuickPlotIcon.xbm"

void SetIconImage(Widget w, Boolean flag)
{
  Pixmap pixmap;
  Pixel foreground, background;
  unsigned int depth;
  unsigned int width = QuickPlotIcon_width;
  unsigned int height = QuickPlotIcon_height;

  XtVaGetValues(w,XtNdepth, &depth, NULL);
  foreground = XBlackPixelOfScreen(XtScreen(w));
  background = XWhitePixelOfScreen(XtScreen(w));

  pixmap = XCreatePixmapFromBitmapData(
	    XtDisplay(w),
	    XRootWindowOfScreen(XtScreen(w)),
	    (char *) QuickPlotIcon_bits,
	    width,
	    height,
	    foreground,
	    background,
	    depth);
  XtVaSetValues(w, XtNiconPixmap, pixmap, NULL);

}
